==> open-cluster-management-operator-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/IngressSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.function.Predicate;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class IngressSpecFluent<A extends IngressSpecFluent<A>> extends BaseFluent<A>{
  public IngressSpecFluent() {
  }
  
  public IngressSpecFluent(IngressSpec instance) {
    this.copyInstance(instance);
  }
  private List<String> sslCiphers = new ArrayList<String>();
  
  protected void copyInstance(IngressSpec instance) {
    instance = (instance != null ? instance : new IngressSpec());
    if (instance != null) {
          this.withSslCiphers(instance.getSslCiphers());
          this.withSslCiphers(instance.getSslCiphers());
        }
  }
  
  public A addToSslCiphers(int index,String item) {
    if (this.sslCiphers == null) {this.sslCiphers = new ArrayList<String>();}
    this.sslCiphers.add(index, item);
    return (A)this;
  }
  
  public A setToSslCiphers(int index,String item) {
    if (this.sslCiphers == null) {this.sslCiphers = new ArrayList<String>();}
    this.sslCiphers.set(index, item); return (A)this;
  }
  
  public A addToSslCiphers(java.lang.String... items) {
    if (this.sslCiphers == null) {this.sslCiphers = new ArrayList<String>();}
    for (String item : items) {this.sslCiphers.add(item);} return (A)this;
  }
  
  public A addAllToSslCiphers(Collection<String> items) {
    if (this.sslCiphers == null) {this.sslCiphers = new ArrayList<String>();}
    for (String item : items) {this.sslCiphers.add(item);} return (A)this;
  }
  
  public A removeFromSslCiphers(java.lang.String... items) {
    if (this.sslCiphers == null) return (A)this;
    for (String item : items) { this.sslCiphers.remove(item);} return (A)this;
  }
  
  public A removeAllFromSslCiphers(Collection<String> items) {
    if (this.sslCiphers == null) return (A)this;
    for (String item : items) { this.sslCiphers.remove(item);} return (A)this;
  }
  
  public List<String> getSslCiphers() {
    return this.sslCiphers;
  }
  
  public String getSslCipher(int index) {
    return this.sslCiphers.get(index);
  }
  
  public String getFirstSslCipher() {
    return this.sslCiphers.get(0);
  }
  
  public String getLastSslCipher() {
    return this.sslCiphers.get(sslCiphers.size() - 1);
  }
  
  public String getMatchingSslCipher(Predicate<String> predicate) {
      for (String item : sslCiphers) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingSslCipher(Predicate<String> predicate) {
      for (String item : sslCiphers) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withSslCiphers(List<String> sslCiphers) {
    if (sslCiphers != null) {
        this.sslCiphers = new ArrayList();
        for (String item : sslCiphers) {
          this.addToSslCiphers(item);
        }
    } else {
      this.sslCiphers = null;
    }
    return (A) this;
  }
  
  public A withSslCiphers(java.lang.String... sslCiphers) {
    if (this.sslCiphers != null) {this.sslCiphers.clear(); _visitables.remove("sslCiphers"); }
    if (sslCiphers != null) {for (String item :sslCiphers){ this.addToSslCiphers(item);}} return (A) this;
  }
  
  public boolean hasSslCiphers() {
    return this.sslCiphers != null && !this.sslCiphers.isEmpty();
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressSpecFluent that = (IngressSpecFluent) o;
    if (!java.util.Objects.equals(sslCiphers, that.sslCiphers)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(sslCiphers,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (sslCiphers != null && !sslCiphers.isEmpty()) { sb.append("sslCiphers:"); sb.append(sslCiphers); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> open-cluster-management-operator-model-6.13.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/IngressSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class IngressSpecFluent<A extends IngressSpecFluent<A>> extends BaseFluent<A>{
  public IngressSpecFluent() {
  }
  
  public IngressSpecFluent(IngressSpec instance) {
    this.copyInstance(instance);
  }
  private List<String> sslCiphers = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(IngressSpec instance) {
    instance = (instance != null ? instance : new IngressSpec());
    if (instance != null) {
          this.withSslCiphers(instance.getSslCiphers());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToSslCiphers(int index,String item) {
    if (this.sslCiphers == null) {this.sslCiphers = new ArrayList<String>();}
    this.sslCiphers.add(index, item);
    return (A)this;
  }
  
  public A setToSslCiphers(int index,String item) {
    if (this.sslCiphers == null) {this.sslCiphers = new ArrayList<String>();}
    this.sslCiphers.set(index, item); return (A)this;
  }
  
  public A addToSslCiphers(java.lang.String... items) {
    if (this.sslCiphers == null) {this.sslCiphers = new ArrayList<String>();}
    for (String item : items) {this.sslCiphers.add(item);} return (A)this;
  }
  
  public A addAllToSslCiphers(Collection<String> items) {
    if (this.sslCiphers == null) {this.sslCiphers = new ArrayList<String>();}
    for (String item : items) {this.sslCiphers.add(item);} return (A)this;
  }
  
  public A removeFromSslCiphers(java.lang.String... items) {
    if (this.sslCiphers == null) return (A)this;
    for (String item : items) { this.sslCiphers.remove(item);} return (A)this;
  }
  
  public A removeAllFromSslCiphers(Collection<String> items) {
    if (this.sslCiphers == null) return (A)this;
    for (String item : items) { this.sslCiphers.remove(item);} return (A)this;
  }
  
  public List<String> getSslCiphers() {
    return this.sslCiphers;
  }
  
  public String getSslCipher(int index) {
    return this.sslCiphers.get(index);
  }
  
  public String getFirstSslCipher() {
    return this.sslCiphers.get(0);
  }
  
  public String getLastSslCipher() {
    return this.sslCiphers.get(sslCiphers.size() - 1);
  }
  
  public String getMatchingSslCipher(Predicate<String> predicate) {
      for (String item : sslCiphers) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingSslCipher(Predicate<String> predicate) {
      for (String item : sslCiphers) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withSslCiphers(List<String> sslCiphers) {
    if (sslCiphers != null) {
        this.sslCiphers = new ArrayList();
        for (String item : sslCiphers) {
          this.addToSslCiphers(item);
        }
    } else {
      this.sslCiphers = null;
    }
    return (A) this;
  }
  
  public A withSslCiphers(java.lang.String... sslCiphers) {
    if (this.sslCiphers != null) {
        this.sslCiphers.clear();
        _visitables.remove("sslCiphers");
    }
    if (sslCiphers != null) {
      for (String item : sslCiphers) {
        this.addToSslCiphers(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasSslCiphers() {
    return this.sslCiphers != null && !this.sslCiphers.isEmpty();
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressSpecFluent that = (IngressSpecFluent) o;
    if (!java.util.Objects.equals(sslCiphers, that.sslCiphers)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(sslCiphers,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (sslCiphers != null && !sslCiphers.isEmpty()) { sb.append("sslCiphers:"); sb.append(sslCiphers + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
